@@ -1,20 +1,8 @@
 /*
- *  Copyright (C) 2002, 2003 David Faure   <faure@kde.org>
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License version 2 as published by the Free Software Foundation;
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+    SPDX-FileCopyrightText: 2002, 2003 David Faure <faure@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-only
+*/
 
 #include "kurifiltertest.h"
 
@@ -178,7 +166,7 @@ void KUriFilterTest::initTestCase()
     qDebug() << "libpaths" << QCoreApplication::libraryPaths();
 
     qputenv("KDE_FORK_SLAVES", "yes");   // simpler, for the final cleanup
-    QLoggingCategory::setFilterRules(QStringLiteral("org.kde.kurifilter-*=true"));
+    QLoggingCategory::setFilterRules(QStringLiteral("kf.kio.urifilters.*=true"));
 
     QString searchProvidersDir = QFINDTESTDATA("../src/urifilters/ikws/searchproviders/google.desktop").section('/', 0, -2);
     QVERIFY(!searchProvidersDir.isEmpty());
@@ -375,10 +363,10 @@ void KUriFilterTest::shortUris_data()
     addRow("http:", QStringLiteral("http:"), KUriFilterData::NetProtocol);
 
     // The default search engine is set to 'Google'
-    //this may fail if your DNS knows domains KDE or FTP
     addRow("gg:", QLatin1String(""), KUriFilterData::NetProtocol);   // see bug 56218
-    addRow("KDE", QStringLiteral("https://www.google.com/search?q=KDE&ie=UTF-8"), KUriFilterData::NetProtocol);
-    addRow("HTTP", QStringLiteral("https://www.google.com/search?q=HTTP&ie=UTF-8"), KUriFilterData::NetProtocol);
+    // disable localdomain in case the local DNS or /etc/hosts knows domains KDE or HTTP (e.g. due to search domain)
+    addRow("KDE", QStringLiteral("https://www.google.com/search?q=KDE&ie=UTF-8"), KUriFilterData::NetProtocol, { QStringLiteral("kshorturifilter"), QStringLiteral("kuriikwsfilter") });
+    addRow("HTTP", QStringLiteral("https://www.google.com/search?q=HTTP&ie=UTF-8"), KUriFilterData::NetProtocol, { QStringLiteral("kshorturifilter"), QStringLiteral("kuriikwsfilter") });
 }
 
 void KUriFilterTest::shortUris()
@@ -467,8 +455,8 @@ void KUriFilterTest::environmentVariables()
 void KUriFilterTest::internetKeywords_data()
 {
     setupColumns();
-    addRow(QString::asprintf("gg%cfoo bar", s_delimiter).toUtf8(), QStringLiteral("https://www.google.com/search?q=foo+bar&ie=UTF-8"), KUriFilterData::NetProtocol);
-    addRow(QString::asprintf("bug%c55798", s_delimiter).toUtf8(), QStringLiteral("https://bugs.kde.org/show_bug.cgi?id=55798"), KUriFilterData::NetProtocol);
+    addRow(QString::asprintf("gg%cfoo bar", s_delimiter).toUtf8(), QStringLiteral("https://www.google.com/search?q=foo%20bar&ie=UTF-8"), KUriFilterData::NetProtocol);
+    addRow(QString::asprintf("bug%c55798", s_delimiter).toUtf8(), QStringLiteral("https://bugs.kde.org/buglist.cgi?quicksearch=55798"), KUriFilterData::NetProtocol);
 
     addRow(QString::asprintf("gg%cC++", s_delimiter).toUtf8(), QStringLiteral("https://www.google.com/search?q=C%2B%2B&ie=UTF-8"), KUriFilterData::NetProtocol);
     addRow(QString::asprintf("gg%cC#", s_delimiter).toUtf8(), QStringLiteral("https://www.google.com/search?q=C%23&ie=UTF-8"), KUriFilterData::NetProtocol);
