@@ -1,26 +1,13 @@
-/* This file is part of the KDE project
-   Copyright (C) 2004-2014 David Faure <faure@kde.org>
+/*
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 2004-2014 David Faure <faure@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#include <qtest.h>
+#include <QTest>
 
 #include <QThreadPool>
-#include <QFutureSynchronizer>
 #include <QtConcurrentRun>
 
 #include <kio/job.h>
@@ -36,12 +23,12 @@ private Q_SLOTS:
 
 private:
     struct FileData;
-    bool copyLocalFile(FileData* fileData);
+    bool copyLocalFile(FileData *fileData);
 };
 
 void KIOThreadTest::initTestCase()
 {
-    QStandardPaths::enableTestMode(true);
+    QStandardPaths::setTestModeEnabled(true);
 
     // To avoid a runtime dependency on klauncher
     qputenv("KDE_FORK_SLAVES", "yes");
@@ -59,13 +46,12 @@ void KIOThreadTest::cleanupTestCase()
     QDir(homeTmpDir()).removeRecursively();
 }
 
-struct KIOThreadTest::FileData
-{
+struct KIOThreadTest::FileData {
     QString src;
     QString dest;
 };
 
-bool KIOThreadTest::copyLocalFile(FileData* fileData)
+bool KIOThreadTest::copyLocalFile(FileData *fileData)
 {
     // to verify the test harness: return QFile::copy(fileData->src, fileData->dest);
 
@@ -75,22 +61,12 @@ bool KIOThreadTest::copyLocalFile(FileData* fileData)
     // copy the file with file_copy
     KIO::Job *job = KIO::file_copy(u, d, -1, KIO::HideProgressInfo);
     //qDebug() << job << u << d;
-    job->setUiDelegate(0);
+    job->setUiDelegate(nullptr);
     bool ret = job->exec();
     //qDebug() << job << "done";
     return ret;
 }
 
-static bool allFinished(const QList<QFuture<bool> > &futures)
-{
-    for (int i = 0; i < futures.count(); ++i) {
-        if (!futures.at(i).isFinished()) {
-            return false;
-        }
-    }
-    return true;
-}
-
 void KIOThreadTest::concurrentCopying()
 {
     const int numThreads = 20;
@@ -100,17 +76,17 @@ void KIOThreadTest::concurrentCopying()
         data[i].dest = homeTmpDir() + "file" + QString::number(i) + "_copied";
         createTestFile(data[i].src);
     }
-    QThreadPool::globalInstance()->setMaxThreadCount(numThreads);
-    QFutureSynchronizer<bool> sync;
+    QThreadPool tp;
+    tp.setMaxThreadCount(numThreads);
+    QVector<QFuture<bool>> futures(numThreads);
     for (int i = 0; i < numThreads; ++i) {
-        sync.addFuture(QtConcurrent::run(this, &KIOThreadTest::copyLocalFile, &data[i]));
+        futures[i] = QtConcurrent::run(&tp, this, &KIOThreadTest::copyLocalFile, &data[i]);
     }
-    // same as sync.waitForFinished() but with a timeout
-    QTRY_VERIFY(allFinished(sync.futures()));
+    QVERIFY(tp.waitForDone(60000));
 
     for (int i = 0; i < numThreads; ++i) {
         QVERIFY(QFile::exists(data[i].dest));
-        QVERIFY(sync.futures().at(i).result());
+        QVERIFY(futures.at(i).result());
     }
 }
 
