@@ -1,21 +1,9 @@
 /*
-   This file is part of the KDE libraries
-   Copyright (c) 2003 Waldo Bastian <bastian@kde.org>
-                 2007 David Faure <faure@kde.org>
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2003 Waldo Bastian <bastian@kde.org>
+    SPDX-FileCopyrightText: 2007 David Faure <faure@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #ifndef KMOUNTPOINT_H
@@ -24,7 +12,7 @@
 #include "kiocore_export.h"
 #include <QExplicitlySharedDataPointer>
 
-#include <QtCore/QStringList>
+#include <QStringList>
 
 /**
  * @class KMountPoint kmountpoint.h <KMountPoint>
@@ -58,7 +46,7 @@ public:
          * Returns the mount point associated with @p device,
          * i.e. the one where mountedFrom() == @p device
          * (after symlink resolution).
-         * @return the mountpoint, or 0 if this device doesn't exist or isn't mounted
+         * @return the mountpoint, or @c nullptr if this device doesn't exist or isn't mounted
          */
         Ptr findByDevice(const QString &device) const;
     };
@@ -68,8 +56,12 @@ public:
      * BasicInfoNeeded: only the basic details: mountedFrom, mountPoint, mountType.
      * NeedMountOptions: also fetch the options used when mounting, see mountOptions.
      * NeedRealDeviceName: also fetch the device name (with symlinks resolved), see realDeviceName.
+     * @see DetailsNeededFlags
      */
     enum DetailsNeededFlag { BasicInfoNeeded = 0, NeedMountOptions = 1, NeedRealDeviceName = 2 };
+    /**
+     * Stores a combination of #DetailsNeededFlag values.
+     */
     Q_DECLARE_FLAGS(DetailsNeededFlags, DetailsNeededFlag)
 
     /**
@@ -83,6 +75,8 @@ public:
      * This function gives a list of all currently used mountpoints. (mtab)
      * @param infoNeeded Flags that specify which additional information
      * should be fetched.
+     *
+     * @note this method will return an empty list on Android
      */
     static List currentMountPoints(DetailsNeededFlags infoNeeded = BasicInfoNeeded);
 
@@ -129,7 +123,7 @@ public:
      * @param flag the flag to check
      * @return true if the filesystem has that flag, false if not
      *
-     * The availables flags are:
+     * The available flags are:
      * @li SupportsChmod: returns true if the filesystem supports chmod
      * (e.g. msdos filesystems return false)
      * @li SupportsChown: returns true if the filesystem supports chown
