@@ -1,25 +1,12 @@
 /*
- *  This file is part of the KDE libraries
- *  Copyright (c) 2000 Waldo Bastian <bastian@kde.org>
- *  Copyright (c) 2000 David Faure <faure@kde.org>
- *  Copyright (c) 2000 Stephan Kulow <coolo@kde.org>
- *  Copyright (c) 2007 Thiago Macieira <thiago@kde.org>
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License version 2 as published by the Free Software Foundation.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- *
- **/
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2000 Waldo Bastian <bastian@kde.org>
+    SPDX-FileCopyrightText: 2000 David Faure <faure@kde.org>
+    SPDX-FileCopyrightText: 2000 Stephan Kulow <coolo@kde.org>
+    SPDX-FileCopyrightText: 2007 Thiago Macieira <thiago@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-only
+*/
 
 #include "slavebase.h"
 
@@ -41,10 +28,10 @@
 #include <QDataStream>
 #include <QMap>
 
-#include <kconfig.h>
-#include <kconfiggroup.h>
-#include <kcrash.h>
-#include <klocalizedstring.h>
+#include <KConfig>
+#include <KConfigGroup>
+#include <KCrash>
+#include <KLocalizedString>
 
 #include "kremoteencoding.h"
 
@@ -753,6 +740,7 @@ void SlaveBase::infoMessage(const QString &_msg)
     send(INF_INFOMESSAGE, data);
 }
 
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 0)
 bool SlaveBase::requestNetwork(const QString &host)
 {
     KIO_DATA << host << d->slaveid;
@@ -767,12 +755,15 @@ bool SlaveBase::requestNetwork(const QString &host)
         return false;
     }
 }
+#endif
 
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 0)
 void SlaveBase::dropNetwork(const QString &host)
 {
     KIO_DATA << host << d->slaveid;
     send(MSG_NET_DROP, data);
 }
+#endif
 
 void SlaveBase::statEntry(const UDSEntry &entry)
 {
@@ -780,6 +771,7 @@ void SlaveBase::statEntry(const UDSEntry &entry)
     send(MSG_STAT_ENTRY, data);
 }
 
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 0)
 void SlaveBase::listEntry(const UDSEntry &entry, bool _ready)
 {
     if (_ready) {
@@ -794,6 +786,7 @@ void SlaveBase::listEntry(const UDSEntry &entry, bool _ready)
         listEntry(entry);
     }
 }
+#endif
 
 void SlaveBase::listEntry(const UDSEntry &entry)
 {
@@ -998,11 +991,13 @@ void SlaveBase::reparseConfiguration()
     d->remotefile = nullptr;
 }
 
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 24)
 bool SlaveBase::openPasswordDialog(AuthInfo &info, const QString &errorMsg)
 {
     const int errorCode = openPasswordDialogV2(info, errorMsg);
     return errorCode == KJob::NoError;
 }
+#endif
 
 int SlaveBase::openPasswordDialogV2(AuthInfo &info, const QString &errorMsg)
 {
