@@ -1,28 +1,15 @@
-/*******************************************************************************
- *   Copyright (C) 2008-2009 by Peter Penz <peter.penz@gmx.at>                 *
- *                                                                             *
- *   This library is free software; you can redistribute it and/or             *
- *   modify it under the terms of the GNU Library General Public               *
- *   License as published by the Free Software Foundation; either              *
- *   version 2 of the License, or (at your option) any later version.          *
- *                                                                             *
- *   This library is distributed in the hope that it will be useful,           *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of            *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU         *
- *   Library General Public License for more details.                          *
- *                                                                             *
- *   You should have received a copy of the GNU Library General Public License *
- *   along with this library; see the file COPYING.LIB.  If not, write to      *
- *   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,      *
- *   Boston, MA 02110-1301, USA.                                               *
- *******************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2008-2009 Peter Penz <peter.penz@gmx.at>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #ifndef KFILEPREVIEWGENERATOR_H
 #define KFILEPREVIEWGENERATOR_H
 
 #include "kiofilewidgets_export.h"
 
-#include <QtCore/QObject>
+#include <QObject>
 
 class KAbstractViewAdapter;
 class KDirModel;
@@ -78,10 +65,13 @@ public:
     void setPreviewShown(bool show);
     bool isPreviewShown() const;
 
+#if KIOFILEWIDGETS_ENABLE_DEPRECATED_SINCE(4, 3)
     /**
-     * @deprecated Use KFilePreviewGenerator::updateIcons() instead.
+     * @deprecated Since 4.3, use KFilePreviewGenerator::updateIcons() instead.
      */
+    KIOFILEWIDGETS_DEPRECATED_VERSION(4, 3, "Use KFilePreviewGenerator::updateIcons()")
     void updatePreviews();
+#endif
 
     /**
      * Sets the list of enabled thumbnail plugins.
