@@ -1,22 +1,9 @@
-/*****************************************************************************
- * Copyright (C) 2006 by Peter Penz <peter.penz@gmx.at>                      *
- * Copyright (C) 2006 by Aaron J. Seigo <aseigo@kde.org>                     *
- *                                                                           *
- * This library is free software; you can redistribute it and/or             *
- * modify it under the terms of the GNU Library General Public               *
- * License as published by the Free Software Foundation; either              *
- * version 2 of the License, or (at your option) any later version.          *
- *                                                                           *
- * This library is distributed in the hope that it will be useful,           *
- * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU         *
- * Library General Public License for more details.                          *
- *                                                                           *
- * You should have received a copy of the GNU Library General Public License *
- * along with this library; see the file COPYING.LIB.  If not, write to      *
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,      *
- * Boston, MA 02110-1301, USA.                                               *
- *****************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2006 Peter Penz <peter.penz@gmx.at>
+    SPDX-FileCopyrightText: 2006 Aaron J. Seigo <aseigo@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #include "kurlnavigatorbutton_p.h"
 
@@ -26,8 +13,8 @@
 #include "../pathhelpers_p.h"
 
 #include <kio/job.h>
-#include <klocalizedstring.h>
-#include <kstringhandler.h>
+#include <KLocalizedString>
+#include <KStringHandler>
 
 #include <QTimer>
 #include <QPainter>
@@ -143,7 +130,7 @@ QSize KUrlNavigatorButton::sizeHint() const
     adjustedFont.setBold(m_subDir.isEmpty());
     // the minimum size is textWidth + arrowWidth() + 2 * BorderWidth; for the
     // preferred size we add the BorderWidth 2 times again for having an uncluttered look
-    const int width = QFontMetrics(adjustedFont).boundingRect(plainText()).width() + arrowWidth() + 4 * BorderWidth;
+    const int width = QFontMetrics(adjustedFont).size(Qt::TextSingleLine, plainText()).width() + arrowWidth() + 4 * BorderWidth;
     return QSize(width, KUrlNavigatorButtonBase::sizeHint().height());
 }
 
@@ -336,7 +323,7 @@ void KUrlNavigatorButton::dragMoveEvent(QDragMoveEvent *event)
         if (m_openSubDirsTimer->isActive()) {
             cancelSubDirsRequest();
         }
-        delete m_subDirsMenu;
+        m_subDirsMenu->deleteLater();
         m_subDirsMenu = nullptr;
         m_hoverArrow = false;
         update();
@@ -645,7 +632,7 @@ bool KUrlNavigatorButton::isTextClipped() const
 
     QFont adjustedFont(font());
     adjustedFont.setBold(m_subDir.isEmpty());
-    return QFontMetrics(adjustedFont).boundingRect(plainText()).width() >= availableWidth;
+    return QFontMetrics(adjustedFont).size(Qt::TextSingleLine, plainText()).width() >= availableWidth;
 }
 
 void KUrlNavigatorButton::updateMinimumWidth()
