@@ -1,25 +1,11 @@
 /*
-   Copyright (C) 2000-2002 Stephan Kulow <coolo@kde.org>
-   Copyright (C) 2000-2002 David Faure <faure@kde.org>
-   Copyright (C) 2000-2002 Waldo Bastian <bastian@kde.org>
-   Copyright (C) 2006 Allan Sandfeld Jensen <sandfeld@kde.org>
-   Copyright (C) 2007 Thiago Macieira <thiago@kde.org>
+    SPDX-FileCopyrightText: 2000-2002 Stephan Kulow <coolo@kde.org>
+    SPDX-FileCopyrightText: 2000-2002 David Faure <faure@kde.org>
+    SPDX-FileCopyrightText: 2000-2002 Waldo Bastian <bastian@kde.org>
+    SPDX-FileCopyrightText: 2006 Allan Sandfeld Jensen <sandfeld@kde.org>
+    SPDX-FileCopyrightText: 2007 Thiago Macieira <thiago@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License (LGPL) as published by the Free Software Foundation;
-   either version 2 of the License, or (at your option) any later
-   version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "file.h"
@@ -52,17 +38,17 @@
 #include <QVarLengthArray>
 #include <QCoreApplication>
 #include <QFile>
-#include <qtemporaryfile.h>
+#include <QTemporaryFile>
 #ifdef Q_OS_WIN
 #include <QDir>
 #include <QFileInfo>
 #endif
 
 #include <QDebug>
-#include <kconfiggroup.h>
-#include <kshell.h>
+#include <KConfigGroup>
+#include <KShell>
 #include <kmountpoint.h>
-#include <klocalizedstring.h>
+#include <KLocalizedString>
 #include <QMimeDatabase>
 #include <QStandardPaths>
 #include <QDataStream>
@@ -75,7 +61,7 @@
 #include <kdirnotify.h>
 #include <ioslave_defaults.h>
 
-Q_LOGGING_CATEGORY(KIO_FILE, "kf5.kio.kio_file")
+Q_LOGGING_CATEGORY(KIO_FILE, "kf.kio.slaves.file")
 
 // Pseudo plugin class to embed meta data
 class KIOPluginForMetaData : public QObject
