@@ -1,26 +1,12 @@
 /*
-   Copyright (C) 2000-2002 Stephan Kulow <coolo@kde.org>
-   Copyright (C) 2000-2002 David Faure <faure@kde.org>
-   Copyright (C) 2000-2002 Waldo Bastian <bastian@kde.org>
-   Copyright (C) 2006 Allan Sandfeld Jensen <sandfeld@kde.org>
-   Copyright (C) 2007 Thiago Macieira <thiago@kde.org>
-   Copyright (C) 2007 Christian Ehrlicher <ch.ehrlicher@gmx.de>
+    SPDX-FileCopyrightText: 2000-2002 Stephan Kulow <coolo@kde.org>
+    SPDX-FileCopyrightText: 2000-2002 David Faure <faure@kde.org>
+    SPDX-FileCopyrightText: 2000-2002 Waldo Bastian <bastian@kde.org>
+    SPDX-FileCopyrightText: 2006 Allan Sandfeld Jensen <sandfeld@kde.org>
+    SPDX-FileCopyrightText: 2007 Thiago Macieira <thiago@kde.org>
+    SPDX-FileCopyrightText: 2007 Christian Ehrlicher <ch.ehrlicher@gmx.de>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License (LGPL) as published by the Free Software Foundation;
-   either version 2 of the License, or (at your option) any later
-   version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "file.h"
@@ -34,13 +20,14 @@
 #include <QThread>
 
 #include <QDebug>
-#include <kconfiggroup.h>
-#include <klocalizedstring.h>
+#include <KConfigGroup>
+#include <KLocalizedString>
 #include <kmountpoint.h>
 
 #include <errno.h>
 #if HAVE_SYS_XATTR_H
 #include <sys/xattr.h>
+#include <stdint.h>
 #endif
 #include <utime.h>
 
@@ -48,19 +35,28 @@
 #include <KRandom>
 
 #include "fdreceiver.h"
+#include "statjob.h"
+
+#if HAVE_STATX
+#include <sys/stat.h>
+#include <sys/sysmacros.h> // for makedev()
+#endif
+
+#ifdef Q_OS_LINUX
+#include <sys/ioctl.h>
+#include <linux/fs.h>
+#endif
 
 //sendfile has different semantics in different platforms
 #if HAVE_SENDFILE && defined Q_OS_LINUX
 #define USE_SENDFILE 1
-#endif
-
-#ifdef USE_SENDFILE
 #include <sys/sendfile.h>
 #endif
 
 using namespace KIO;
 
-#define MAX_IPC_SIZE (1024*32)
+/* 512 kB */
+#define MAX_IPC_SIZE (1024*512)
 
 static bool
 same_inode(const QT_STATBUF &src, const QT_STATBUF &dest)
@@ -135,6 +131,356 @@ bool FileProtocol::privilegeOperationUnitTestMode()
             && (requestPrivilegeOperation(QStringLiteral("Test Call")) == KIO::OperationAllowed);
 }
 
+/*************************************
+ *
+ * ACL handling helpers
+ *
+ *************************************/
+#if HAVE_POSIX_ACL
+
+static QString aclToText(acl_t acl)
+{
+    ssize_t size = 0;
+    char *txt = acl_to_text(acl, &size);
+    const QString ret = QString::fromLatin1(txt, size);
+    acl_free(txt);
+    return ret;
+}
+
+bool FileProtocol::isExtendedACL(acl_t acl)
+{
+    return (acl_equiv_mode(acl, nullptr) != 0);
+}
+
+static void appendACLAtoms(const QByteArray &path, UDSEntry &entry, mode_t type)
+{
+    // first check for a noop
+    if (acl_extended_file(path.data()) == 0) {
+        return;
+    }
+
+    acl_t acl = nullptr;
+    acl_t defaultAcl = nullptr;
+    bool isDir = (type & QT_STAT_MASK) == QT_STAT_DIR;
+    // do we have an acl for the file, and/or a default acl for the dir, if it is one?
+    acl = acl_get_file(path.data(), ACL_TYPE_ACCESS);
+    /* Sadly libacl does not provided a means of checking for extended ACL and default
+     * ACL separately. Since a directory can have both, we need to check again. */
+    if (isDir) {
+        if (acl) {
+            if (!FileProtocol::isExtendedACL(acl)) {
+                acl_free(acl);
+                acl = nullptr;
+            }
+        }
+        defaultAcl = acl_get_file(path.data(), ACL_TYPE_DEFAULT);
+    }
+    if (acl || defaultAcl) {
+        // qDebug() << path.constData() << "has extended ACL entries";
+        entry.fastInsert(KIO::UDSEntry::UDS_EXTENDED_ACL, 1);
+
+        if (acl) {
+            const QString str = aclToText(acl);
+            entry.fastInsert(KIO::UDSEntry::UDS_ACL_STRING, str);
+            // qDebug() << path.constData() << "ACL:" << str;
+            acl_free(acl);
+        }
+
+        if (defaultAcl) {
+            const QString str = aclToText(defaultAcl);
+            entry.fastInsert(KIO::UDSEntry::UDS_DEFAULT_ACL_STRING, str);
+            // qDebug() << path.constData() << "DEFAULT ACL:" << str;
+            acl_free(defaultAcl);
+        }
+    }
+}
+#endif
+
+static QHash<KUserId, QString> staticUserCache;
+static QHash<KGroupId, QString> staticGroupCache;
+
+static QString getUserName(KUserId uid)
+{
+    if (Q_UNLIKELY(!uid.isValid())) {
+        return QString();
+    }
+    auto it = staticUserCache.find(uid);
+    if (it == staticUserCache.end()) {
+        KUser user(uid);
+        QString name = user.loginName();
+        if (name.isEmpty()) {
+            name = uid.toString();
+        }
+        it = staticUserCache.insert(uid, name);
+    }
+    return *it;
+}
+
+static QString getGroupName(KGroupId gid)
+{
+    if (Q_UNLIKELY(!gid.isValid())) {
+        return QString();
+    }
+    auto it = staticGroupCache.find(gid);
+    if (it == staticGroupCache.end()) {
+        KUserGroup group(gid);
+        QString name = group.name();
+        if (name.isEmpty()) {
+            name = gid.toString();
+        }
+        it = staticGroupCache.insert(gid, name);
+    }
+    return *it;
+}
+
+#if HAVE_STATX
+// statx syscall is available
+inline int LSTAT(const char* path, struct statx * buff, KIO::StatDetails details) {
+    uint32_t mask = 0;
+    if (details & KIO::StatBasic) {
+        // filename, access, type, size, linkdest
+        mask |= STATX_SIZE | STATX_TYPE;
+    }
+    if (details & KIO::StatUser) {
+        // uid, gid
+        mask |= STATX_UID | STATX_GID;
+    }
+    if (details & KIO::StatTime) {
+        // atime, mtime, btime
+        mask |= STATX_ATIME | STATX_MTIME | STATX_BTIME;
+    }
+    if (details & KIO::StatInode) {
+        // dev, inode
+        mask |= STATX_INO;
+    }
+    return statx(AT_FDCWD, path, AT_SYMLINK_NOFOLLOW, mask, buff);
+}
+inline int STAT(const char* path, struct statx * buff, KIO::StatDetails details) {
+    uint32_t mask = 0;
+    // KIO::StatAcl needs type
+    if (details & (KIO::StatBasic | KIO::StatAcl | KIO::StatResolveSymlink)) {
+        // filename, access, type
+        mask |= STATX_TYPE;
+    }
+    if (details & (KIO::StatBasic | KIO::StatResolveSymlink)) {
+        // size, linkdest
+        mask |= STATX_SIZE;
+    }
+    if (details & KIO::StatUser) {
+        // uid, gid
+        mask |= STATX_UID | STATX_GID;
+    }
+    if (details & KIO::StatTime) {
+        // atime, mtime, btime
+        mask |= STATX_ATIME | STATX_MTIME | STATX_BTIME;
+    }
+    // KIO::Inode is ignored as when STAT is called, the entry inode field has already been filled
+    return statx(AT_FDCWD, path, AT_STATX_SYNC_AS_STAT, mask, buff);
+}
+inline static uint16_t stat_mode(struct statx &buf) { return buf.stx_mode; }
+inline static dev_t stat_dev(struct statx &buf) { return makedev(buf.stx_dev_major, buf.stx_dev_minor); }
+inline static uint64_t stat_ino(struct statx &buf) { return buf.stx_ino; }
+inline static uint64_t stat_size(struct statx &buf) { return buf.stx_size; }
+inline static uint32_t stat_uid(struct statx &buf) { return buf.stx_uid; }
+inline static uint32_t stat_gid(struct statx &buf) { return buf.stx_gid; }
+inline static int64_t stat_atime(struct statx &buf) { return buf.stx_atime.tv_sec; }
+inline static int64_t stat_mtime(struct statx &buf) { return buf.stx_mtime.tv_sec; }
+#else
+// regular stat struct
+inline int LSTAT(const char* path, QT_STATBUF * buff, KIO::StatDetails details) {
+    Q_UNUSED(details)
+    return QT_LSTAT(path, buff);
+}
+inline int STAT(const char* path, QT_STATBUF * buff, KIO::StatDetails details) {
+    Q_UNUSED(details)
+    return QT_STAT(path, buff);
+}
+inline static mode_t stat_mode(QT_STATBUF &buf) { return buf.st_mode; }
+inline static dev_t stat_dev(QT_STATBUF &buf) { return buf.st_dev; }
+inline static ino_t stat_ino(QT_STATBUF &buf) { return buf.st_ino; }
+inline static off_t stat_size(QT_STATBUF &buf) { return buf.st_size; }
+inline static uid_t stat_uid(QT_STATBUF &buf) { return buf.st_uid; }
+inline static gid_t stat_gid(QT_STATBUF &buf) { return buf.st_gid; }
+inline static time_t stat_atime(QT_STATBUF &buf) { return buf.st_atime; }
+inline static time_t stat_mtime(QT_STATBUF &buf) { return buf.st_mtime; }
+#endif
+
+static bool createUDSEntry(const QString &filename, const QByteArray &path, UDSEntry &entry,
+                                  KIO::StatDetails details)
+{
+    assert(entry.count() == 0); // by contract :-)
+    int entries = 0;
+    if (details & KIO::StatBasic) {
+        // filename, access, type, size, linkdest
+        entries += 5;
+    }
+    if (details & KIO::StatUser) {
+        // uid, gid
+        entries += 2;
+    }
+    if (details & KIO::StatTime) {
+        // atime, mtime, btime
+        entries += 3;
+    }
+    if (details & KIO::StatAcl) {
+        // acl data
+        entries += 3;
+    }
+    if (details & KIO::StatInode) {
+        // dev, inode
+        entries += 2;
+    }
+    entry.reserve(entries);
+
+    if (details & KIO::StatBasic) {
+        entry.fastInsert(KIO::UDSEntry::UDS_NAME, filename);
+    }
+
+    bool isBrokenSymLink = false;
+#if HAVE_POSIX_ACL
+    QByteArray targetPath = path;
+#endif
+
+#if HAVE_STATX
+    // statx syscall is available
+    struct statx buff;
+#else
+    QT_STATBUF buff;
+#endif
+
+    if (LSTAT(path.data(), &buff, details) == 0)  {
+
+        if ((stat_mode(buff) & QT_STAT_MASK) == QT_STAT_LNK) {
+
+            QByteArray linkTargetBuffer;
+            if (details & (KIO::StatBasic|KIO::StatResolveSymlink)) {
+
+                // Use readlink on Unix because symLinkTarget turns relative targets into absolute (#352927)
+                #if HAVE_STATX
+                    size_t lowerBound = 256;
+                    size_t higherBound = 1024;
+                    uint64_t s = stat_size(buff);
+                    if (s > SIZE_MAX) {
+                        qCWarning(KIO_FILE) << "file size bigger than SIZE_MAX, too big for readlink use!" << path;
+                        return false;
+                    }
+                    size_t size = static_cast<size_t>(s);
+                    using SizeType = size_t;
+                #else
+                    off_t lowerBound = 256;
+                    off_t higherBound = 1024;
+                    off_t size = stat_size(buff);
+                    using SizeType = off_t;
+                #endif
+                SizeType bufferSize = qBound(lowerBound, size +1, higherBound);
+                linkTargetBuffer.resize(bufferSize);
+                while (true) {
+                    ssize_t n = readlink(path.constData(), linkTargetBuffer.data(), bufferSize);
+                    if (n < 0 && errno != ERANGE) {
+                        qCWarning(KIO_FILE) << "readlink failed!" << path;
+                        return false;
+                    } else if (n > 0 && static_cast<SizeType>(n) != bufferSize) {
+                        // the buffer was not filled in the last iteration
+                        // we are finished reading, break the loop
+                        linkTargetBuffer.truncate(n);
+                        break;
+                    }
+                    bufferSize *= 2;
+                    linkTargetBuffer.resize(bufferSize);
+                }
+                const QString linkTarget = QFile::decodeName(linkTargetBuffer);
+                entry.fastInsert(KIO::UDSEntry::UDS_LINK_DEST, linkTarget);
+            }
+
+            // A symlink
+            if (details & KIO::StatResolveSymlink) {
+                if (STAT(path.constData(), &buff, details) == -1) {
+                    isBrokenSymLink = true;
+                } else {
+#if HAVE_POSIX_ACL
+                    if (details & KIO::StatAcl) {
+                        // valid symlink, will get the ACLs of the destination
+                        targetPath = linkTargetBuffer;
+                    }
+#endif
+                }
+            }
+        }
+    } else {
+        // qCWarning(KIO_FILE) << "lstat didn't work on " << path.data();
+        return false;
+    }
+
+    mode_t type = 0;
+    if (details & (KIO::StatBasic | KIO::StatAcl)) {
+        mode_t access;
+        signed long long size;
+        if (isBrokenSymLink) {
+            // It is a link pointing to nowhere
+            type = S_IFMT - 1;
+            access = S_IRWXU | S_IRWXG | S_IRWXO;
+            size = 0LL;
+        } else {
+            type = stat_mode(buff) & S_IFMT; // extract file type
+            access = stat_mode(buff) & 07777; // extract permissions
+            size = stat_size(buff);
+        }
+
+        if (details & KIO::StatBasic) {
+            entry.fastInsert(KIO::UDSEntry::UDS_FILE_TYPE, type);
+            entry.fastInsert(KIO::UDSEntry::UDS_ACCESS, access);
+            entry.fastInsert(KIO::UDSEntry::UDS_SIZE, size);
+        }
+
+#if HAVE_POSIX_ACL
+        if (details & KIO::StatAcl) {
+            /* Append an atom indicating whether the file has extended acl information
+             * and if withACL is specified also one with the acl itself. If it's a directory
+             * and it has a default ACL, also append that. */
+            appendACLAtoms(targetPath, entry, type);
+        }
+#endif
+    }
+
+    if (details & KIO::StatUser) {
+        entry.fastInsert(KIO::UDSEntry::UDS_USER, getUserName(KUserId(stat_uid(buff))));
+        entry.fastInsert(KIO::UDSEntry::UDS_GROUP, getGroupName(KGroupId(stat_gid(buff))));
+    }
+
+    if (details & KIO::StatTime) {
+        entry.fastInsert(KIO::UDSEntry::UDS_MODIFICATION_TIME, stat_mtime(buff));
+        entry.fastInsert(KIO::UDSEntry::UDS_ACCESS_TIME, stat_atime(buff));
+
+#ifdef st_birthtime
+        /* For example FreeBSD's and NetBSD's stat contains a field for
+         * the inode birth time: st_birthtime
+         * This however only works on UFS and ZFS, and not, on say, NFS.
+         * Instead of setting a bogus fallback like st_mtime, only use
+         * it if it is greater than 0. */
+        if (buff.st_birthtime > 0) {
+            entry.fastInsert(KIO::UDSEntry::UDS_CREATION_TIME, buff.st_birthtime);
+        }
+#elif defined __st_birthtime
+        /* As above, but OpenBSD calls it slightly differently. */
+        if (buff.__st_birthtime > 0) {
+            entry.fastInsert(KIO::UDSEntry::UDS_CREATION_TIME, buff.__st_birthtime);
+        }
+#elif HAVE_STATX
+        /* And linux version using statx syscall */
+        if (buff.stx_mask & STATX_BTIME) {
+            entry.fastInsert(KIO::UDSEntry::UDS_CREATION_TIME, buff.stx_btime.tv_sec);
+        }
+#endif
+    }
+
+    if (details & KIO::StatInode) {
+        entry.fastInsert(KIO::UDSEntry::UDS_DEVICE_ID, stat_dev(buff));
+        entry.fastInsert(KIO::UDSEntry::UDS_INODE, stat_ino(buff));
+    }
+
+    return true;
+}
+
 PrivilegeOperationReturnValue FileProtocol::tryOpen(QFile &f, const QByteArray &path, int flags, int mode, int errcode)
 {
     const QString sockPath = socketPath();
@@ -189,7 +535,7 @@ void FileProtocol::copy(const QUrl &srcUrl, const QUrl &destUrl,
         return;
     }
 
-    // qDebug() << "copy(): " << srcUrl << " -> " << destUrl << ", mode=" << _mode;
+    qCDebug(KIO_FILE) << "copy()" << srcUrl << "to" << destUrl << "mode=" << _mode;
 
     const QString src = srcUrl.toLocalFile();
     QString dest = destUrl.toLocalFile();
@@ -305,85 +651,65 @@ void FileProtocol::copy(const QUrl &srcUrl, const QUrl &destUrl,
 #endif
     totalSize(buff_src.st_size);
 
-    KIO::filesize_t processed_size = 0;
-    char buffer[ MAX_IPC_SIZE ];
-    ssize_t n = 0;
-#ifdef USE_SENDFILE
-    bool use_sendfile = buff_src.st_size < 0x7FFFFFFF;
+#ifdef FICLONE
+    // Share data blocks ("reflink") on supporting filesystems, like brfs and XFS
+    int ret = ::ioctl (dest_file.handle(), FICLONE, src_file.handle());
+    if (ret != -1) {
+        processedSize(src_file.size());
+    } else {
+        // if fs does not support reflinking, files are on different devices...
 #endif
-    bool existing_dest_delete_attempted = false;
-    while (!wasKilled()) {
-
-        if (testMode && dest_file.fileName().contains(QLatin1String("slow"))) {
-            QThread::usleep(500);
-        }
-
+        KIO::filesize_t processed_size = 0;
+        char buffer[ MAX_IPC_SIZE ];
+        ssize_t n = 0;
 #ifdef USE_SENDFILE
-        if (use_sendfile) {
-            off_t sf = processed_size;
-            n = ::sendfile(dest_file.handle(), src_file.handle(), &sf, MAX_IPC_SIZE);
-            processed_size = sf;
-            if (n == -1 && (errno == EINVAL || errno == ENOSYS)) {     //not all filesystems support sendfile()
-                // qDebug() << "sendfile() not supported, falling back ";
-                use_sendfile = false;
-            }
-        }
-        if (!use_sendfile)
+        bool use_sendfile = true;
 #endif
-            n = ::read(src_file.handle(), buffer, MAX_IPC_SIZE);
+        bool existing_dest_delete_attempted = false;
+        while (!wasKilled()) {
 
-        if (n == -1) {
-            if (errno == EINTR) {
-                continue;
+            if (testMode && dest_file.fileName().contains(QLatin1String("slow"))) {
+                QThread::msleep(50);
             }
+
 #ifdef USE_SENDFILE
             if (use_sendfile) {
-                // qDebug() << "sendfile() error:" << strerror(errno);
-                if (errno == ENOSPC) { // disk full
-                    if (!_dest_backup.isEmpty() && !existing_dest_delete_attempted) {
-                        ::unlink(_dest_backup.constData());
-                        existing_dest_delete_attempted = true;
-                        continue;
-                    }
-                    error(KIO::ERR_DISK_FULL, dest);
-                } else {
-                    error(KIO::ERR_SLAVE_DEFINED,
-                          i18n("Cannot copy file from %1 to %2. (Errno: %3)",
-                               src, dest, errno));
+                off_t sf = processed_size;
+                n = ::sendfile(dest_file.handle(), src_file.handle(), &sf, MAX_IPC_SIZE);
+                processed_size = sf;
+                if (n == -1 && (errno == EINVAL || errno == ENOSYS)) {     //not all filesystems support sendfile()
+                    // qDebug() << "sendfile() not supported, falling back ";
+                    use_sendfile = false;
                 }
-            } else
-#endif
-                error(KIO::ERR_CANNOT_READ, src);
-            src_file.close();
-            dest_file.close();
-#if HAVE_POSIX_ACL
-            if (acl) {
-                acl_free(acl);
             }
+            if (!use_sendfile)
 #endif
-            if (!QFile::remove(dest)) {  // don't keep partly copied file
-                execWithElevatedPrivilege(DEL, {_dest}, errno);
-            }
-            return;
-        }
-        if (n == 0) {
-            break;    // Finished
-        }
+                n = ::read(src_file.handle(), buffer, MAX_IPC_SIZE);
+
+            if (n == -1) {
+                if (errno == EINTR) {
+                    continue;
+                }
 #ifdef USE_SENDFILE
-        if (!use_sendfile) {
-#endif
-            if (dest_file.write(buffer, n) != n) {
-                if (dest_file.error() == QFileDevice::ResourceError) {  // disk full
-                    if (!_dest_backup.isEmpty() && !existing_dest_delete_attempted) {
-                        ::unlink(_dest_backup.constData());
-                        existing_dest_delete_attempted = true;
-                        continue;
+                if (use_sendfile) {
+                    // qDebug() << "sendfile() error:" << strerror(errno);
+                    if (errno == ENOSPC) { // disk full
+                        if (!_dest_backup.isEmpty() && !existing_dest_delete_attempted) {
+                            ::unlink(_dest_backup.constData());
+                            existing_dest_delete_attempted = true;
+                            continue;
+                        }
+                        error(KIO::ERR_DISK_FULL, dest);
+                    } else {
+                        error(KIO::ERR_SLAVE_DEFINED,
+                              i18n("Cannot copy file from %1 to %2. (Errno: %3)",
+                                   src, dest, errno));
                     }
-                    error(KIO::ERR_DISK_FULL, dest);
-                } else {
-                    qCWarning(KIO_FILE) << "Couldn't write[2]. Error:" << dest_file.errorString();
-                    error(KIO::ERR_CANNOT_WRITE, dest);
-                }
+                } else
+#endif
+                    error(KIO::ERR_CANNOT_READ, src);
+                src_file.close();
+                dest_file.close();
 #if HAVE_POSIX_ACL
                 if (acl) {
                     acl_free(acl);
@@ -394,14 +720,71 @@ void FileProtocol::copy(const QUrl &srcUrl, const QUrl &destUrl,
                 }
                 return;
             }
-            processed_size += n;
+            if (n == 0) {
+                break;    // Finished
+            }
 #ifdef USE_SENDFILE
-        }
+            if (!use_sendfile) {
 #endif
-        processedSize(processed_size);
+                if (dest_file.write(buffer, n) != n) {
+                    if (dest_file.error() == QFileDevice::ResourceError) {  // disk full
+                        if (!_dest_backup.isEmpty() && !existing_dest_delete_attempted) {
+                            ::unlink(_dest_backup.constData());
+                            existing_dest_delete_attempted = true;
+                            continue;
+                        }
+                        error(KIO::ERR_DISK_FULL, dest);
+                    } else {
+                        qCWarning(KIO_FILE) << "Couldn't write[2]. Error:" << dest_file.errorString();
+                        error(KIO::ERR_CANNOT_WRITE, dest);
+                    }
+#if HAVE_POSIX_ACL
+                    if (acl) {
+                        acl_free(acl);
+                    }
+#endif
+                    if (!QFile::remove(dest)) {  // don't keep partly copied file
+                        execWithElevatedPrivilege(DEL, {_dest}, errno);
+                    }
+                    return;
+                }
+                processed_size += n;
+#ifdef USE_SENDFILE
+            }
+#endif
+            processedSize(processed_size);
+        }
+#ifdef FICLONE
     }
+#endif
 
     src_file.close();
+
+    dest_file.flush(); // so the write() happens before futimes()
+
+    // copy access and modification time
+    if (!wasKilled()) {
+    #ifdef Q_OS_LINUX
+        // with nano secs precision
+        struct timespec ut[2];
+        ut[0] = buff_src.st_atim;
+        ut[1] = buff_src.st_mtim;
+        // need to do this with the dest file still opened, or this fails
+        if (::futimens(dest_file.handle(), ut) != 0) {
+    #else
+        struct timeval ut[2];
+        ut[0].tv_sec = buff_src.st_atime;
+        ut[0].tv_usec = 0;
+        ut[1].tv_sec = buff_src.st_mtime;
+        ut[1].tv_usec = 0;
+        if (::futimes(dest_file.handle(), ut) != 0) {
+    #endif
+            if (tryChangeFileAttr(UTIME, {_dest, qint64(buff_src.st_atime), qint64(buff_src.st_mtime)}, errno)) {
+                qCWarning(KIO_FILE) << "Couldn't preserve access and modification time for" << dest;
+            }
+        }
+    }
+
     dest_file.close();
 
     if (wasKilled()) {
@@ -466,16 +849,6 @@ void FileProtocol::copy(const QUrl &srcUrl, const QUrl &destUrl,
         }
     }
 
-    // copy access and modification time
-    struct utimbuf ut;
-    ut.actime = buff_src.st_atime;
-    ut.modtime = buff_src.st_mtime;
-    if (::utime(_dest.data(), &ut) != 0) {
-        if (tryChangeFileAttr(UTIME, {_dest, qint64(ut.actime), qint64(ut.modtime)}, errno)) {
-            qCWarning(KIO_FILE) << "Couldn't preserve access and modification time for" << dest;
-        }
-    }
-
     if (!_dest_backup.isEmpty()) {
         if (::unlink(_dest_backup.constData()) == -1) {
             qCWarning(KIO_FILE) << "Couldn't remove original dest" <<  _dest_backup << "(" << strerror(errno) << ")";
@@ -514,40 +887,24 @@ static bool isNtfsHidden(const QString &filename)
 {
     constexpr auto attrName = "system.ntfs_attrib_be";
     const auto filenameEncoded = QFile::encodeName(filename);
-#ifdef Q_OS_MACOS
-    auto length = getxattr(filenameEncoded.data(), attrName, nullptr, 0, 0, XATTR_NOFOLLOW);
-#else
-    auto length = getxattr(filenameEncoded.data(), attrName, nullptr, 0);
-#endif
-    if (length <= 0) {
-        return false;
-    }
-    constexpr size_t xattr_size = 1024;
+
+    uint32_t intAttr = 0;
+    constexpr size_t xattr_size = sizeof(intAttr);
     char strAttr[xattr_size];
 #ifdef Q_OS_MACOS
-    length = getxattr(filenameEncoded.data(), attrName, strAttr, xattr_size, 0, XATTR_NOFOLLOW);
+    auto length = getxattr(filenameEncoded.data(), attrName, strAttr, xattr_size, 0, XATTR_NOFOLLOW);
 #else
-    length = getxattr(filenameEncoded.data(), attrName, strAttr, xattr_size);
+    auto length = getxattr(filenameEncoded.data(), attrName, strAttr, xattr_size);
 #endif
     if (length <= 0) {
         return false;
     }
 
-    // Decode result to hex string
-    static constexpr auto digits = "0123456789abcdef";
-    QVarLengthArray<char> hexAttr(static_cast<int>(length) * 2 + 4);
     char *c = strAttr;
-    char *e = hexAttr.data();
-    *e++ ='0';
-    *e++ = 'x';
-    for (auto n = 0; n < length; n++, c++) {
-        *e++ = digits[(static_cast<uchar>(*c) >> 4)];
-        *e++ = digits[(static_cast<uchar>(*c) & 0x0F)];
+    for (decltype(length) n = 0; n < length; ++n, ++c) {
+        intAttr <<= 8;
+        intAttr |= static_cast<uchar>(*c);
     }
-    *e = '\0';
-
-    // Decode hex string to int
-    auto intAttr = static_cast<uint>(strtol(hexAttr.data(), nullptr, 16));
 
     constexpr auto FILE_ATTRIBUTE_HIDDEN = 0x2u;
     return static_cast<bool>(intAttr & FILE_ATTRIBUTE_HIDDEN);
@@ -603,8 +960,7 @@ void FileProtocol::listDir(const QUrl &url)
         return;
     }
 
-    const QString sDetails = metaData(QStringLiteral("details"));
-    const int details = sDetails.isEmpty() ? 2 : sDetails.toInt();
+    const KIO::StatDetails details = getStatDetails();
     //qDebug() << "========= LIST " << url << "details=" << details << " =========";
     UDSEntry entry;
 
@@ -627,7 +983,7 @@ void FileProtocol::listDir(const QUrl &url)
          * for every entry thus becoming slower.
          *
          */
-        if (details == 0) {
+        if (details == KIO::StatBasic) {
             entry.fastInsert(KIO::UDSEntry::UDS_NAME, filename);
 #ifdef HAVE_DIRENT_D_TYPE
             entry.fastInsert(KIO::UDSEntry::UDS_FILE_TYPE,
@@ -705,6 +1061,18 @@ void FileProtocol::rename(const QUrl &srcUrl, const QUrl &destUrl,
     // with its target (#169547)
     bool dest_exists = (QT_LSTAT(_dest.data(), &buff_dest) != -1);
     if (dest_exists) {
+        // Try QFile::rename(), this can help when renaming 'a' to 'A' on a case-insensitive
+        // filesystem, e.g. FAT32/VFAT.
+        if (src != dest && QString::compare(src, dest, Qt::CaseInsensitive) == 0) {
+            qCDebug(KIO_FILE) << "Dest already exists; detected special case of lower/uppercase renaming"
+                              << "in same dir on a case-insensitive filesystem, try with QFile::rename()"
+                              << "(which uses 2 rename calls)";
+            if (QFile::rename(src, dest)) {
+                finished();
+                return;
+            }
+        }
+
         if (same_inode(buff_dest, buff_src)) {
             error(KIO::ERR_IDENTICAL_FILES, dest);
             return;
@@ -721,7 +1089,7 @@ void FileProtocol::rename(const QUrl &srcUrl, const QUrl &destUrl,
         }
     }
 
-    if (::rename(_src.data(), _dest.data())) {
+    if (::rename(_src.data(), _dest.data()) == -1) {
         if (auto err = execWithElevatedPrivilege(RENAME, {_src, _dest}, errno)) {
             if (!err.wasCanceled()) {
                 if ((err == EACCES) || (err == EPERM)) {
@@ -892,6 +1260,25 @@ void FileProtocol::chown(const QUrl &url, const QString &owner, const QString &g
     }
 }
 
+KIO::StatDetails FileProtocol::getStatDetails()
+{
+    // takes care of converting old metadata details to new StatDetails
+    // TODO KF6 : remove legacy "details" code path
+    KIO::StatDetails details;
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 69)
+    if (hasMetaData(QStringLiteral("statDetails"))) {
+#endif
+        const QString statDetails = metaData(QStringLiteral("statDetails"));
+        details = statDetails.isEmpty() ? KIO::StatDefaultDetails : static_cast<KIO::StatDetails>(statDetails.toInt());
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 69)
+    } else {
+        const QString sDetails = metaData(QStringLiteral("details"));
+        details = sDetails.isEmpty() ? KIO::StatDefaultDetails : KIO::detailsToStatDetails(sDetails.toInt());
+    }
+#endif
+    return details;
+}
+
 void FileProtocol::stat(const QUrl &url)
 {
     if (!isLocalFileSameHost(url)) {
@@ -908,8 +1295,8 @@ void FileProtocol::stat(const QUrl &url)
      */
     const QString path(url.adjusted(QUrl::StripTrailingSlash).toLocalFile());
     const QByteArray _path(QFile::encodeName(path));
-    const QString sDetails = metaData(QStringLiteral("details"));
-    const int details = sDetails.isEmpty() ? 2 : sDetails.toInt();
+
+    const KIO::StatDetails details = getStatDetails();
 
     UDSEntry entry;
     if (!createUDSEntry(url.fileName(), _path, entry, details)) {
@@ -990,3 +1377,50 @@ PrivilegeOperationReturnValue FileProtocol::execWithElevatedPrivilege(ActionType
 
     return PrivilegeOperationReturnValue::failure(KIO::ERR_ACCESS_DENIED);
 }
+
+int FileProtocol::setACL(const char *path, mode_t perm, bool directoryDefault)
+{
+    int ret = 0;
+#if HAVE_POSIX_ACL
+
+    const QString ACLString = metaData(QStringLiteral("ACL_STRING"));
+    const QString defaultACLString = metaData(QStringLiteral("DEFAULT_ACL_STRING"));
+    // Empty strings mean leave as is
+    if (!ACLString.isEmpty()) {
+        acl_t acl = nullptr;
+        if (ACLString == QLatin1String("ACL_DELETE")) {
+            // user told us to delete the extended ACL, so let's write only
+            // the minimal (UNIX permission bits) part
+            acl = acl_from_mode(perm);
+        }
+        acl = acl_from_text(ACLString.toLatin1().constData());
+        if (acl_valid(acl) == 0) {     // let's be safe
+            ret = acl_set_file(path, ACL_TYPE_ACCESS, acl);
+            // qDebug() << "Set ACL on:" << path << "to:" << aclToText(acl);
+        }
+        acl_free(acl);
+        if (ret != 0) {
+            return ret;    // better stop trying right away
+        }
+    }
+
+    if (directoryDefault && !defaultACLString.isEmpty()) {
+        if (defaultACLString == QLatin1String("ACL_DELETE")) {
+            // user told us to delete the default ACL, do so
+            ret += acl_delete_def_file(path);
+        } else {
+            acl_t acl = acl_from_text(defaultACLString.toLatin1().constData());
+            if (acl_valid(acl) == 0) {     // let's be safe
+                ret += acl_set_file(path, ACL_TYPE_DEFAULT, acl);
+                // qDebug() << "Set Default ACL on:" << path << "to:" << aclToText(acl);
+            }
+            acl_free(acl);
+        }
+    }
+#else
+    Q_UNUSED(path);
+    Q_UNUSED(perm);
+    Q_UNUSED(directoryDefault);
+#endif
+    return ret;
+}
