@@ -1,26 +1,12 @@
 /*
-   Copyright (C) 2000-2002 Stephan Kulow <coolo@kde.org>
-   Copyright (C) 2000-2002 David Faure <faure@kde.org>
-   Copyright (C) 2000-2002 Waldo Bastian <bastian@kde.org>
-   Copyright (C) 2006 Allan Sandfeld Jensen <sandfeld@kde.org>
-   Copyright (C) 2007 Thiago Macieira <thiago@kde.org>
-   Copyright (C) 2007 Christian Ehrlicher <ch.ehrlicher@gmx.de>
+    SPDX-FileCopyrightText: 2000-2002 Stephan Kulow <coolo@kde.org>
+    SPDX-FileCopyrightText: 2000-2002 David Faure <faure@kde.org>
+    SPDX-FileCopyrightText: 2000-2002 Waldo Bastian <bastian@kde.org>
+    SPDX-FileCopyrightText: 2006 Allan Sandfeld Jensen <sandfeld@kde.org>
+    SPDX-FileCopyrightText: 2007 Thiago Macieira <thiago@kde.org>
+    SPDX-FileCopyrightText: 2007 Christian Ehrlicher <ch.ehrlicher@gmx.de>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License (LGPL) as published by the Free Software Foundation;
-   either version 2 of the License, or (at your option) any later
-   version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "file.h"
@@ -31,7 +17,7 @@
 #include <QDirIterator>
 #include <QFileInfo>
 
-#include <kconfiggroup.h>
+#include <KConfigGroup>
 #include <QDebug>
 
 #include "kioglobal_p.h"
@@ -104,6 +90,7 @@ static UDSEntry createUDSEntryWin(const QFileInfo &fileInfo)
     entry.insert(KIO::UDSEntry::UDS_USER, fileInfo.owner());
     entry.insert(KIO::UDSEntry::UDS_GROUP, fileInfo.group());
     entry.insert(KIO::UDSEntry::UDS_ACCESS_TIME, fileInfo.lastRead().toSecsSinceEpoch());
+    entry.insert(KIO::UDSEntry::UDS_CREATION_TIME, fileInfo.birthTime().toSecsSinceEpoch());
 
     return entry;
 }
@@ -400,3 +387,11 @@ PrivilegeOperationReturnValue FileProtocol::tryChangeFileAttr(ActionType, const
 {
     return PrivilegeOperationReturnValue::failure(err);
 }
+
+int FileProtocol::setACL(const char *path, mode_t perm, bool directoryDefault)
+{
+    Q_UNUSED(path);
+    Q_UNUSED(perm);
+    Q_UNUSED(directoryDefault);
+    return 0;
+}
