@@ -1,21 +1,9 @@
-/* This file is part of the KDE libraries
-    Copyright (C) 2008 Andreas Hartmetz <ahartmetz@gmail.com>
-    Copyright (C) 2010,2011 Rolf Eike Beer <kde@opensource.sf-tec.de>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2008 Andreas Hartmetz <ahartmetz@gmail.com>
+    SPDX-FileCopyrightText: 2010, 2011 Rolf Eike Beer <kde@opensource.sf-tec.de>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include <ctype.h>
@@ -23,7 +11,6 @@
 #include <QDir>
 #include <QMap>
 #include <QTextCodec>
-#include <QUrl>
 
 #include <QDebug>
 
@@ -109,6 +96,7 @@ QByteArray TokenIterator::current() const
 QList<QByteArray> TokenIterator::all() const
 {
     QList<QByteArray> ret;
+    ret.reserve(m_tokens.count());
     for (int i = 0; i < m_tokens.count(); i++) {
         QPair<int, int> token = m_tokens[i];
         ret.append(QByteArray(&m_buffer[token.first], token.second - token.first));
@@ -161,8 +149,7 @@ HeaderTokenizer::HeaderTokenizer(char *buffer)
         {"www-authenticate", false} //see proxy-authenticate
     };
 
-    for (uint i = 0; i < sizeof(headerFieldTemplates) / sizeof(HeaderFieldTemplate); i++) {
-        const HeaderFieldTemplate &ft = headerFieldTemplates[i];
+    for (const HeaderFieldTemplate &ft : headerFieldTemplates) {
         insert(QByteArray(ft.name), HeaderField(ft.isMultiValued));
     }
 }
@@ -304,7 +291,7 @@ static bool specialChar(const QChar &ch, const char *specials)
     // characters should NOT be allowed in unquoted content-disposition file
     // names. However, since none of the major browsers follow this rule, we do
     // the same thing here and allow all printable unicode characters. See
-    // https://bugs.kde.org/show_bug.cgi?id=261223 for the detials.
+    // https://bugs.kde.org/show_bug.cgi?id=261223 for the details.
     if (!ch.isPrint()) {
         return true;
     }
@@ -440,7 +427,7 @@ static QMap<QString, QString> contentDispositionParserInternal(const QString &di
         return parameters;
     }
 
-    parameters.insert(QLatin1String("type"), strDisposition);
+    parameters.insert(QStringLiteral("type"), strDisposition);
 
     while (pos < disposition.length()) {
         QString key = extractUntil(disposition, QLatin1Char('='), pos, attrSpecials).toLower();
@@ -547,9 +534,8 @@ static QMap<QString, QString> contentDispositionParserInternal(const QString &di
             continue;
         }
 
-        const QString charset = val.left(spos);
-        const QString lang = val.mid(spos + 1, npos - spos - 1);
-        const QByteArray encodedVal = val.mid(npos + 1).toLatin1();
+        const QStringRef charset = val.leftRef(spos);
+        const QByteArray encodedVal = val.midRef(npos + 1).toLatin1();
 
         if (! isValidPercentEncoding(encodedVal)) {
             continue;
