@@ -1,23 +1,9 @@
 /*
-   This file is part of the KDE project
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 2009 Tobias Koenig <tokoe@kde.org>
+    SPDX-FileCopyrightText: 2014 David Faure <faure@kde.org>
 
-   Copyright (C) 2009 Tobias Koenig <tokoe@kde.org>
-   Copyright (C) 2014 David Faure <faure@kde.org>
-
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "trashsizecache.h"
@@ -31,7 +17,6 @@
 #include <QFile>
 #include <QDateTime>
 #include <QSaveFile>
-#include <QDebug>
 
 TrashSizeCache::TrashSizeCache(const QString &path)
     : mTrashSizeCachePath(path + QLatin1String("/directorysizes")),
@@ -40,11 +25,17 @@ TrashSizeCache::TrashSizeCache(const QString &path)
     //qCDebug(KIO_TRASH) << "CACHE:" << mTrashSizeCachePath;
 }
 
+// Only the last part of the line: space, directory name, '\n'
+static QByteArray spaceAndDirectoryAndNewline(const QString &directoryName)
+{
+    const QByteArray encodedDir = QFile::encodeName(directoryName).toPercentEncoding();
+    return ' ' + encodedDir + '\n';
+}
+
 void TrashSizeCache::add(const QString &directoryName, qulonglong directorySize)
 {
     //qCDebug(KIO_TRASH) << directoryName << directorySize;
-    const QByteArray encodedDir = QFile::encodeName(directoryName).toPercentEncoding();
-    const QByteArray spaceAndDirAndNewline = ' ' + encodedDir + '\n';
+    const QByteArray spaceAndDirAndNewline = spaceAndDirectoryAndNewline(directoryName);
     QFile file(mTrashSizeCachePath);
     QSaveFile out(mTrashSizeCachePath);
     if (out.open(QIODevice::WriteOnly)) {
@@ -61,8 +52,7 @@ void TrashSizeCache::add(const QString &directoryName, qulonglong directorySize)
             }
         }
 
-        const QString fileInfoPath = mTrashPath + "/info/" + directoryName + ".trashinfo";
-        QDateTime mtime = QFileInfo(fileInfoPath).lastModified();
+        QDateTime mtime = getTrashFileInfo(directoryName).lastModified();
         QByteArray newLine = QByteArray::number(directorySize) + ' ' + QByteArray::number(mtime.toMSecsSinceEpoch()) + spaceAndDirAndNewline;
         out.write(newLine);
         out.commit();
@@ -73,8 +63,7 @@ void TrashSizeCache::add(const QString &directoryName, qulonglong directorySize)
 void TrashSizeCache::remove(const QString &directoryName)
 {
     //qCDebug(KIO_TRASH) << directoryName;
-    const QByteArray encodedDir = QFile::encodeName(directoryName).toPercentEncoding();
-    const QByteArray spaceAndDirAndNewline = ' ' + encodedDir + '\n';
+    const QByteArray spaceAndDirAndNewline = spaceAndDirectoryAndNewline(directoryName);
     QFile file(mTrashSizeCachePath);
     QSaveFile out(mTrashSizeCachePath);
     if (file.open(QIODevice::ReadOnly) && out.open(QIODevice::WriteOnly)) {
@@ -90,31 +79,55 @@ void TrashSizeCache::remove(const QString &directoryName)
     out.commit();
 }
 
+void TrashSizeCache::rename(const QString &oldDirectoryName, const QString &newDirectoryName)
+{
+    const QByteArray spaceAndDirAndNewline = spaceAndDirectoryAndNewline(oldDirectoryName);
+    QFile file(mTrashSizeCachePath);
+    QSaveFile out(mTrashSizeCachePath);
+    if (file.open(QIODevice::ReadOnly) && out.open(QIODevice::WriteOnly)) {
+        while (!file.atEnd()) {
+            QByteArray line = file.readLine();
+            if (line.endsWith(spaceAndDirAndNewline)) {
+                // Found it -> rename it, keeping the size
+                line = line.left(line.length() - spaceAndDirAndNewline.length()) + spaceAndDirectoryAndNewline(newDirectoryName);
+            }
+            out.write(line);
+        }
+    }
+    out.commit();
+}
+
 void TrashSizeCache::clear()
 {
     QFile::remove(mTrashSizeCachePath);
 }
 
-struct CacheData {
-    qint64 mtime;
-    qulonglong size;
-};
-
 qulonglong TrashSizeCache::calculateSize()
+{
+    return this->calculateSizeAndLatestModDate().size;
+}
+
+QFileInfo TrashSizeCache::getTrashFileInfo(const QString &fileName)
+{
+    const QString fileInfoPath = mTrashPath + QLatin1String("/info/") + fileName + QLatin1String(".trashinfo");
+    return QFileInfo(fileInfoPath);
+}
+
+TrashSizeCache::SizeAndModTime TrashSizeCache::calculateSizeAndLatestModDate()
 {
     // First read the directorysizes cache into memory
     QFile file(mTrashSizeCachePath);
-    typedef QHash<QByteArray, CacheData> DirCacheHash;
+    typedef QHash<QByteArray, SizeAndModTime> DirCacheHash;
     DirCacheHash dirCache;
     if (file.open(QIODevice::ReadOnly)) {
         while (!file.atEnd()) {
             const QByteArray line = file.readLine();
             const int firstSpace = line.indexOf(' ');
             const int secondSpace = line.indexOf(' ', firstSpace + 1);
-            CacheData data;
-            data.mtime = line.left(firstSpace).toLongLong();
+            SizeAndModTime data;
+            data.size = line.left(firstSpace).toULongLong();
             // "012 4567 name" -> firstSpace=3, secondSpace=8, we want mid(4,4)
-            data.size = line.mid(firstSpace + 1, secondSpace - firstSpace - 1).toULongLong();
+            data.mtime = line.mid(firstSpace + 1, secondSpace - firstSpace - 1).toLongLong();
             dirCache.insert(line.mid(secondSpace + 1), data);
         }
     }
@@ -123,37 +136,57 @@ qulonglong TrashSizeCache::calculateSize()
     QDirIterator it(mTrashPath + QLatin1String("/files/"), QDirIterator::NoIteratorFlags);
 
     qulonglong sum = 0;
+    qint64 max_mtime = 0;
+    const auto checkMaxTime = [&max_mtime] (const qint64 lastModTime) {
+        if (lastModTime > max_mtime) {
+            max_mtime = lastModTime;
+        }
+    };
+    const auto checkLastModTime = [this, checkMaxTime] (const QString &fileName) {
+        const auto trashFileInfo = getTrashFileInfo(fileName);
+        if (!trashFileInfo.exists()) {
+            return;
+        }
+        checkMaxTime(trashFileInfo.lastModified().toMSecsSinceEpoch());
+    };
     while (it.hasNext()) {
-        const QFileInfo file = it.next();
-        if (file.fileName() == QLatin1String(".") || file.fileName() == QLatin1String("..")) {
+        const QFileInfo fileInfo = it.next();
+        const QString fileName = fileInfo.fileName();
+        if (fileName == QLatin1Char('.') || fileName == QLatin1String("..")) {
             continue;
         }
-        if (file.isSymLink()) {
+        if (fileInfo.isSymLink()) {
             // QFileInfo::size does not return the actual size of a symlink. #253776
             QT_STATBUF buff;
-            return static_cast<qulonglong>(QT_LSTAT(QFile::encodeName(file.absoluteFilePath()), &buff) == 0 ? buff.st_size : 0);
-        } else if (file.isFile()) {
-            sum += file.size();
+            if (QT_LSTAT(QFile::encodeName(fileInfo.absoluteFilePath()).constData(), &buff) == 0) {
+                sum += static_cast<unsigned long long>(buff.st_size);
+                checkLastModTime(fileName);
+            }
+        } else if (fileInfo.isFile()) {
+            sum += static_cast<unsigned long long>(fileInfo.size());
+            checkLastModTime(fileName);
         } else {
+            // directories
             bool usableCache = false;
-            const QString fileId = file.fileName();
-            DirCacheHash::const_iterator it = dirCache.constFind(QFile::encodeName(fileId));
+            DirCacheHash::const_iterator it = dirCache.constFind(QFile::encodeName(fileName));
             if (it != dirCache.constEnd()) {
-                const CacheData &data = *it;
-                const QString fileInfoPath = mTrashPath + "/info/" + fileId + ".trashinfo";
-                if (QFileInfo(fileInfoPath).lastModified().toMSecsSinceEpoch() == data.mtime) {
+                const SizeAndModTime &data = *it;
+                const auto trashFileInfo = getTrashFileInfo(fileName);
+                if (trashFileInfo.exists() && trashFileInfo.lastModified().toMSecsSinceEpoch() == data.mtime) {
                     sum += data.size;
                     usableCache = true;
+                    checkMaxTime(data.mtime);
                 }
             }
             if (!usableCache) {
-                const qulonglong size = DiscSpaceUtil::sizeOfPath(file.absoluteFilePath());
+                // directories with no cache data (or outdated)
+                const qulonglong size = DiscSpaceUtil::sizeOfPath(fileInfo.absoluteFilePath());
                 sum += size;
-                add(fileId, size);
+                // NOTE: this does not take into account the directory content modification date
+                checkMaxTime(QFileInfo(fileInfo.absolutePath()).lastModified().toMSecsSinceEpoch());
+                add(fileName, size);
             }
         }
-
     }
-
-    return sum;
+    return {sum, max_mtime};
 }
