@@ -1,20 +1,8 @@
-/**
- * Copyright (c) 2001 Dawit Alemayehu <adawit@kde.org>
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- */
+/*
+    SPDX-FileCopyrightText: 2001 Dawit Alemayehu <adawit@kde.org>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 // Own
 #include "useragentselectordlg.h"
@@ -29,9 +17,9 @@
 #include <QWidget>
 
 // KDE
-#include <kcombobox.h>
+#include <KComboBox>
 #include <QLineEdit>
-#include <kurllabel.h>
+#include <KUrlLabel>
 #include <QVBoxLayout>
 
 
@@ -98,8 +86,13 @@ UserAgentSelectorDlg::UserAgentSelectorDlg (UserAgentInfo* info, QWidget* parent
 
     connect (mUi.siteLineEdit, &QLineEdit::textEdited,
              this, &UserAgentSelectorDlg::onHostNameChanged);
+#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
     connect (mUi.aliasComboBox, QOverload<const QString &>::of(&QComboBox::activated),
              this, &UserAgentSelectorDlg::onAliasChanged);
+#else
+    connect (mUi.aliasComboBox, &QComboBox::textActivated,
+             this, &UserAgentSelectorDlg::onAliasChanged);
+#endif
 
     mButtonBox->button(QDialogButtonBox::Ok)->setEnabled (false);
 }
