@@ -1,25 +1,13 @@
 /*
- * Copyright (c) 2000 Malte Starostik <malte@kde.org>
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- */
+    SPDX-FileCopyrightText: 2000 Malte Starostik <malte@kde.org>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "searchprovider.h"
 
-#include <krandom.h>
-#include <kservicetypetrader.h>
+#include <KRandom>
+#include <KServiceTypeTrader>
 #include <QStandardPaths>
 #include <KIO/Global> // KIO::iconNameForUrl
 #include <QFileInfo>
@@ -38,6 +26,7 @@ SearchProvider::SearchProvider(const QString &servicePath)
     m_query = group.readEntry(QStringLiteral("Query"));
     m_charset = group.readEntry(QStringLiteral("Charset"));
     m_iconName = group.readEntry(QStringLiteral("Icon"));
+    m_isHidden = group.readEntry(QStringLiteral("Hidden"), false);
 }
 
 SearchProvider::~SearchProvider()
@@ -81,7 +70,8 @@ void SearchProvider::setKeys(const QStringList &keys)
     // until the name is unique
     for (const QString &key : keys) {
         if (key.length() > name.length()) {
-            name = key.toLower();
+            // We should avoid hidden files and directory paths, BUG: 407944
+            name = key.toLower().remove(QLatin1Char('.')).remove(QLatin1Char('/'));;
         }
     }
 
