@@ -1,38 +1,23 @@
 /*
- * This file is part of the KDE project.
- *
- * Copyright (C) 2009 - 2012 Dawit Alemayehu <adawit @ kde.org>
- * Copyright (C) 2008 - 2009 Urs Wolfer <uwolfer @ kde.org>
- * Copyright (C) 2007 Trolltech ASA
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
- *
- */
+    This file is part of the KDE project.
+    SPDX-FileCopyrightText: 2009-2012 Dawit Alemayehu <adawit @ kde.org>
+    SPDX-FileCopyrightText: 2008-2009 Urs Wolfer <uwolfer @ kde.org>
+    SPDX-FileCopyrightText: 2007 Trolltech ASA
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #include "accessmanager.h"
 
 #include "accessmanagerreply_p.h"
 #include "job.h"
-#include "kjobwidgets.h"
+#include <KJobWidgets>
 #include "scheduler.h"
 #include "kio_widgets_debug.h"
-#include <kconfiggroup.h>
-#include <ksharedconfig.h>
+#include <KConfigGroup>
+#include <KSharedConfig>
 #include <kprotocolinfo.h>
-#include <klocalizedstring.h>
+#include <KLocalizedString>
 
 #include <QUrl>
 #include <QNetworkCookie>
@@ -128,6 +113,7 @@ bool AccessManager::isExternalContentAllowed() const
     return d->externalContentAllowed;
 }
 
+#if KIOWIDGETS_BUILD_DEPRECATED_SINCE(5, 0)
 void AccessManager::setCookieJarWindowId(WId id)
 {
     QWidget *window = QWidget::find(id);
@@ -142,6 +128,7 @@ void AccessManager::setCookieJarWindowId(WId id)
 
     d->window = window->isWindow() ? window : window->window();
 }
+#endif
 
 void AccessManager::setWindow(QWidget *widget)
 {
@@ -161,6 +148,7 @@ void AccessManager::setWindow(QWidget *widget)
     }
 }
 
+#if KIOWIDGETS_BUILD_DEPRECATED_SINCE(5, 0)
 WId AccessManager::cookieJarWindowid() const
 {
     KIO::Integration::CookieJar *jar = qobject_cast<KIO::Integration::CookieJar *> (cookieJar());
@@ -170,6 +158,7 @@ WId AccessManager::cookieJarWindowid() const
 
     return 0;
 }
+#endif
 
 QWidget *AccessManager::window() const
 {
