@@ -1,25 +1,10 @@
 /*
- * This file is part of the KDE project.
- *
- * Copyright (C) 2008 - 2009 Urs Wolfer <uwolfer @ kde.org>
- * Copyright (C) 2009 - 2012 Dawit Alemayehu <adawit @ kde.org>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
- *
- */
+    This file is part of the KDE project.
+    SPDX-FileCopyrightText: 2008-2009 Urs Wolfer <uwolfer @ kde.org>
+    SPDX-FileCopyrightText: 2009-2012 Dawit Alemayehu <adawit @ kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #ifndef KIO_ACCESSMANAGERREPLY_P_H
 #define KIO_ACCESSMANAGERREPLY_P_H
@@ -96,6 +81,7 @@ private Q_SLOTS:
 
 private:
     QByteArray m_data;
+    qint64 m_offset;
     bool m_metaDataRead;
     bool m_ignoreContentDisposition;
     bool m_emitReadyReadOnMetaDataChange;
