@@ -1,21 +1,8 @@
-/* This file is part of the KDE libraries
-    Copyright (C) 2014 David Faure <faure@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2014 David Faure <faure@kde.org>
 
-    This library is free software; you can redistribute it and/or modify
-    it under the terms of the GNU Lesser General Public License as published by
-    the Free Software Foundation; either version 2 of the License or (at
-    your option) version 3 or, at the discretion of KDE e.V. (which shall
-    act as a proxy as in section 14 of the GPLv3), any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #include "dropjob.h"
@@ -30,6 +17,7 @@
 #include <KConfigGroup>
 #include <KCoreDirLister>
 #include <KDesktopFile>
+#include <KIO/ApplicationLauncherJob>
 #include <KIO/CopyJob>
 #include <KIO/DndPopupMenuPlugin>
 #include <KIO/FileUndoManager>
@@ -41,7 +29,6 @@
 #include <KPluginLoader>
 #include <KProtocolManager>
 #include <KUrlMimeData>
-#include <KRun>
 #include <KService>
 
 #include <QDropEvent>
@@ -90,8 +77,8 @@ public:
           m_keyboardModifiers(dropEvent->keyboardModifiers()),
           m_destUrl(destUrl),
           m_destItem(KCoreDirLister::cachedItemForUrl(destUrl)),
-          m_dropjobFlags(dropjobFlags),
           m_flags(flags),
+          m_dropjobFlags(dropjobFlags),
           m_triggered(false)
     {
         // Check for the drop of a bookmark -> we want a Link action
@@ -542,12 +529,18 @@ void DropJobPrivate::handleDropToDesktopFile()
     const KConfigGroup desktopGroup = desktopFile.desktopGroup();
     if (desktopFile.hasApplicationType()) {
         // Drop to application -> start app with urls as argument
-        KService service(destFile);
-        if (!KRun::runApplication(service, m_urls, KJobWidgets::window(q))) {
-            q->setError(KIO::ERR_CANNOT_LAUNCH_PROCESS);
-            q->setErrorText(destFile);
-        }
-        q->emitResult();
+        KService::Ptr service(new KService(destFile));
+        KIO::ApplicationLauncherJob *job = new KIO::ApplicationLauncherJob(service);
+        job->setUrls(m_urls);
+        job->setUiDelegate(q->uiDelegate());
+        job->start();
+        QObject::connect(job, &KJob::result, q, [=]() {
+            if (job->error()) {
+                q->setError(KIO::ERR_CANNOT_LAUNCH_PROCESS);
+                q->setErrorText(destFile);
+            }
+            q->emitResult();
+        });
     } else if (desktopFile.hasLinkType() && desktopGroup.hasKey(urlKey)) {
         // Drop to link -> adjust destination directory
         m_destUrl = QUrl::fromUserInput(desktopGroup.readPathEntry(urlKey, QString()));
