@@ -1,22 +1,9 @@
 /*
-   This file is part of the KDE project
-   Copyright (C) 2009 Shaun Reich <shaun.reich@kdemail.net>
-   Copyright © 2006-2007, 2008 Fredrik Höglund <fredrik@kde.org>
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 2009 Shaun Reich <shaun.reich@kdemail.net>
+    SPDX-FileCopyrightText: 2006-2007, 2008 Fredrik Höglund <fredrik@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "kfileitemdelegate.h"
@@ -36,16 +23,16 @@
 #include <QListView>
 #include <QPaintEngine>
 #include <qmath.h>
-#include <qmimedatabase.h>
+#include <QMimeDatabase>
 #include <QTextEdit>
 
-#include <klocalizedstring.h>
-#include <kiconloader.h>
-#include <kiconeffect.h>
+#include <KLocalizedString>
+#include <KIconLoader>
+#include <KIconEffect>
 #include <kdirmodel.h>
 #include <kfileitem.h>
-#include <kcolorscheme.h>
-#include <kstringhandler.h>
+#include <KColorScheme>
+#include <KStringHandler>
 
 #include "delegateanimationhandler_p.h"
 
@@ -230,7 +217,7 @@ QString KFileItemDelegate::Private::information(const QStyleOptionViewItem &opti
         return string;
     }
 
-    foreach (KFileItemDelegate::Information info, informationList) {
+    for (KFileItemDelegate::Information info : informationList) {
         if (info == KFileItemDelegate::NoInformation) {
             continue;
         }
@@ -299,7 +286,7 @@ QString KFileItemDelegate::Private::information(const QStyleOptionViewItem &opti
         default:
             break;
         } // switch (info)
-    } // foreach (info, list)
+    } // for (info, list)
 
     return string;
 }
