@@ -1,19 +1,8 @@
-/* This file is part of the KDE libraries
-   Copyright (C) 2000 David Faure <faure@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2000 David Faure <faure@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #include "kio/skipdialog.h"
@@ -24,10 +13,10 @@
 #include <QDialogButtonBox>
 #include <QPushButton>
 #include <QWidget>
-#include <QLayout>
 #include <QLabel>
+#include <QVBoxLayout>
 
-#include <klocalizedstring.h>
+#include <KLocalizedString>
 #include <kio/jobuidelegateextension.h>
 
 using namespace KIO;
@@ -54,7 +43,7 @@ SkipDialog::SkipDialog(QWidget *parent, KIO::SkipDialog_Options options, const Q
         connect(skipButton, &QAbstractButton::clicked, this, &SkipDialog::skipPressed);
         buttonBox->addButton(skipButton, QDialogButtonBox::ActionRole);
 
-        QPushButton *autoSkipButton = new QPushButton(i18n("AutoSkip"));
+        QPushButton *autoSkipButton = new QPushButton(i18n("Skip All"));
         connect(autoSkipButton, &QAbstractButton::clicked, this, &SkipDialog::autoSkipPressed);
         buttonBox->addButton(autoSkipButton, QDialogButtonBox::ActionRole);
     }
